@@ -1,6 +1,7 @@
 library(testthat)
 library(editrules)
 
+context("CorrectRounding")
 
 test_that("correctRounding works",{
    R <- editmatrix(c("a == 1"))
@@ -10,6 +11,7 @@ test_that("correctRounding works",{
 })
 
 
+
 test_that("correctRounding with fixate works",{
    R <- editmatrix(c("a + b == 2"))
    dat <- data.frame(a=2,b=1)
@@ -48,4 +50,34 @@ test_that("correctRounding works with Scholtus 2008 example",{
                     )
    sol <- correctRounding(E,dat)
    expect_equal(as.character(sol$status$status), "corrected")
-})
\ No newline at end of file
+})
+
+
+# smoke test
+context("Smoke test of correctrounding")
+s <- sample(.Machine$integer.max,1)
+cat("Randseed is ",s,":")
+set.seed(s)
+E <- editmatrix(c("x+y==z","x>=0","y>=0"))
+for ( i in 1:10 ){
+    cat(i); flush.console()
+    x <- sample(0:2,10,replace=TRUE)
+    y <- sample(0:2,10,replace=TRUE)
+    z <- x + y + sample(c(-1,1),10,replace=TRUE) 
+    v <- correctRounding(E,data.frame(x=x,y=y,z=z))
+    test_that("No extra inequalities are generated",{
+        expect_equal(sum(violatedEdits(E,v$corrected)[,2:3]),0)
+    })
+}
+
+
+
+
+
+
+
+
+
+
+
+
